@@ -1,4 +1,5 @@
 use fltk::{app, button::Button, frame::Frame, prelude::*, window::Window};
+use std::sync::{Arc, Mutex};
 
 fn main() {
     let app = app::App::default();
@@ -11,11 +12,13 @@ fn main() {
 
     wind.show();
 
+    let frame = Arc::from(Mutex::from(frame));
     but.set_callback(move |_| {
-        let mut frame = frame.clone();
+        let frame = frame.clone();
         std::thread::spawn(move || {
             for i in 0..1000 {
                 app::sleep(0.010);
+                let mut frame = frame.lock().unwrap();
                 frame.set_label(format!("Hello {}", i).as_str());
             }
         });
